@@ -29,11 +29,11 @@ config = {
             # Spatial Database
             "spatial": {
                 # default_db will search in the dbs["database"] as default option
-                "dbname": "fenix",
+                "dbname": "db",
                 "host": "localhost",
                 "port": "5432",
-                "username": "fenix",
-                "password": "Qwaszx",
+                "username": "user",
+                "password": "pwd",
                 "schema": "spatial",
             }
         }
