@@ -4,8 +4,8 @@ from flask import Blueprint
 from flask import Response
 from flask import request
 from flask.ext.cors import cross_origin
-from geobricks_distribution.utils.log import logger
-from geobricks_distribution.core.distribution_core import export_raster_by_spatial_query
+from geobricks_common.core.log import logger
+from geobricks_distribution.core.distribution_core import Distribution
 from geobricks_distribution.config.config import config
 from flask import request, send_from_directory
 
@@ -13,12 +13,24 @@ log = logger(__file__)
 
 app = Blueprint("distribution", "distribution")
 
+
 # TODO: How to map it to the download distribution URL? Get the one in the @app.route "/download/"
 #distribution_url = request.host_url + "distribution/download/"
 
 zip_filename = "layers"
 
 
+@app.route('/')
+@cross_origin(origins='*')
+def root():
+    """
+    Root REST service.
+    @return: Welcome message.
+    """
+    return 'Welcome to Geobricks Distribution!'
+
+
+
 @app.route('/discovery/')
 @app.route('/discovery')
 @cross_origin(origins='*')
@@ -30,26 +42,22 @@ def discovery():
     out = {
         'name': 'Distribution service',
         'description': 'Functionalities to distribute geospatial data.',
-        'type': 'DISTRIBUTION'
+        'type': 'SERVICE'
     }
-    print "----"
-    print request.script_root
-    print request.path
-    print request.base_url
-    print request.url_root
-    print request.url
     return Response(json.dumps(out), content_type='application/json; charset=utf-8')
 
 
-@app.route('/rasters/spatial_query/', methods=['POST'])
-@app.route('/rasters/spatial_query', methods=['POST'])
+@app.route('/raster/spatialquery/', methods=['POST'])
+@app.route('/raster/spatialquery', methods=['POST'])
 @cross_origin(origins='*', headers=['Content-Type'])
 def get_rasters_spatial_query():
     try:
         user_json = request.get_json()
-        distribution_url = request.host_url + config["settings"]["base_url"] + "distribution/download/"
-        distribution_folder = config["settings"]["folders"]["distribution"]
-        result = export_raster_by_spatial_query(user_json, distribution_url, distribution_folder)
+        #TODO: handle it nicer the url to set the distribution download url
+        base_url = config["settings"]["base_url"] if "base_url" in config["settings"] else ""
+        distribution_url = request.host_url + base_url + "distribution/download/"
+        distribution = Distribution(config)
+        result = distribution.export_raster_by_spatial_query(user_json, distribution_url)
         return Response(json.dumps(result), content_type='application/json; charset=utf-8')
     except Exception, e:
         raise Exception(e)
